@@ -17,161 +17,259 @@
 # under the License.
 import re
 import sys
-import time
 import warnings
-from collections import deque
-from datetime import datetime, timedelta
-from logging import Logger
-from threading import Event, Thread
-from typing import Dict, Generator, Optional, Sequence
+from datetime import timedelta
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence
 
-from botocore.exceptions import ClientError, ConnectionClosedError
-from botocore.waiter import Waiter
+import boto3
 
+from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator, XCom
 from airflow.providers.amazon.aws.exceptions import EcsOperatorError, EcsTaskFailToStart
+
+# TODO: Remove the following import when EcsProtocol and EcsTaskLogFetcher deprecations are removed.
+from airflow.providers.amazon.aws.hooks import ecs
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
-from airflow.providers.amazon.aws.hooks.logs import AwsLogsHook
-from airflow.typing_compat import Protocol, runtime_checkable
+from airflow.providers.amazon.aws.hooks.ecs import (
+    EcsClusterStates,
+    EcsHook,
+    EcsTaskDefinitionStates,
+    should_retry_eni,
+)
+from airflow.providers.amazon.aws.sensors.ecs import EcsClusterStateSensor, EcsTaskDefinitionStateSensor
 from airflow.utils.session import provide_session
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
-def should_retry(exception: Exception):
-    """Check if exception is related to ECS resource quota (CPU, MEM)."""
-    if isinstance(exception, EcsOperatorError):
-        return any(
-            quota_reason in failure['reason']
-            for quota_reason in ['RESOURCE:MEMORY', 'RESOURCE:CPU']
-            for failure in exception.failures
-        )
-    return False
+DEFAULT_CONN_ID = 'aws_default'
 
 
-def should_retry_eni(exception: Exception):
-    """Check if exception is related to ENI (Elastic Network Interfaces)."""
-    if isinstance(exception, EcsTaskFailToStart):
-        return any(
-            eni_reason in exception.message
-            for eni_reason in ['network interface provisioning', 'ResourceInitializationError']
-        )
-    return False
+class EcsBaseOperator(BaseOperator):
+    """This is the base operator for all Elastic Container Service operators."""
+
+    def __init__(
+        self, *, aws_conn_id: Optional[str] = DEFAULT_CONN_ID, region: Optional[str] = None, **kwargs
+    ):
+        self.aws_conn_id = aws_conn_id
+        self.region = region
+        super().__init__(**kwargs)
+
+    @cached_property
+    def hook(self) -> EcsHook:
+        """Create and return an EcsHook."""
+        return EcsHook(aws_conn_id=self.aws_conn_id, region_name=self.region)
+
+    @cached_property
+    def client(self) -> boto3.client:
+        """Create and return the EcsHook's client."""
+        return self.hook.conn
+
+    def execute(self, context: 'Context'):
+        """Must overwrite in child classes."""
+        raise NotImplementedError('Please implement execute() in subclass')
 
 
-@runtime_checkable
-class EcsProtocol(Protocol):
+class EcsCreateClusterOperator(EcsBaseOperator):
     """
-    A structured Protocol for ``boto3.client('ecs')``. This is used for type hints on
-    :py:meth:`.EcsOperator.client`.
+    Creates an AWS ECS cluster.
 
     .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EcsCreateClusterOperator`
 
-        - https://mypy.readthedocs.io/en/latest/protocols.html
-        - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html
+    :param cluster_name: The name of your cluster. If you don't specify a name for your
+        cluster, you create a cluster that's named default.
+    :param create_cluster_kwargs: Extra arguments for Cluster Creation.
+    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
     """
 
-    def run_task(self, **kwargs) -> Dict:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.run_task"""  # noqa: E501
-        ...
-
-    def get_waiter(self, x: str) -> Waiter:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.get_waiter"""  # noqa: E501
-        ...
-
-    def describe_tasks(self, cluster: str, tasks) -> Dict:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.describe_tasks"""  # noqa: E501
-        ...
-
-    def stop_task(self, cluster, task, reason: str) -> Dict:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.stop_task"""  # noqa: E501
-        ...
-
-    def describe_task_definition(self, taskDefinition: str) -> Dict:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.describe_task_definition"""  # noqa: E501
-        ...
-
-    def list_tasks(self, cluster: str, launchType: str, desiredStatus: str, family: str) -> Dict:
-        """https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.list_tasks"""  # noqa: E501
-        ...
-
-
-class EcsTaskLogFetcher(Thread):
-    """
-    Fetches Cloudwatch log events with specific interval as a thread
-    and sends the log events to the info channel of the provided logger.
-    """
+    template_fields: Sequence[str] = ('cluster_name', 'create_cluster_kwargs', 'wait_for_completion')
 
     def __init__(
         self,
         *,
-        aws_conn_id: Optional[str] = 'aws_default',
-        region_name: Optional[str] = None,
-        log_group: str,
-        log_stream_name: str,
-        fetch_interval: timedelta,
-        logger: Logger,
+        cluster_name: str,
+        create_cluster_kwargs: Optional[Dict] = None,
+        wait_for_completion: bool = True,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
+        self.cluster_name = cluster_name
+        self.create_cluster_kwargs = create_cluster_kwargs or {}
+        self.wait_for_completion = wait_for_completion
+
+    def execute(self, context: 'Context'):
+        self.log.info(
+            'Creating cluster %s using the following values: %s',
+            self.cluster_name,
+            self.create_cluster_kwargs,
+        )
+        result = self.client.create_cluster(clusterName=self.cluster_name, **self.create_cluster_kwargs)
+
+        if self.wait_for_completion:
+            while not EcsClusterStateSensor(
+                task_id='await_cluster',
+                cluster_name=self.cluster_name,
+            ).poke(context):
+                # The sensor has a built-in delay and will try again until
+                # the cluster is ready or has reached a failed state.
+                pass
+
+        return result['cluster']
+
+
+class EcsDeleteClusterOperator(EcsBaseOperator):
+    """
+    Deletes an AWS ECS cluster.
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EcsDeleteClusterOperator`
+
+    :param cluster_name: The short name or full Amazon Resource Name (ARN) of the cluster to delete.
+    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
+    """
+
+    template_fields: Sequence[str] = ('cluster_name', 'wait_for_completion')
+
+    def __init__(
+        self,
+        *,
+        cluster_name: str,
+        wait_for_completion: bool = True,
+        **kwargs,
+    ) -> None:
+        super().__init__(**kwargs)
+        self.cluster_name = cluster_name
+        self.wait_for_completion = wait_for_completion
+
+    def execute(self, context: 'Context'):
+        self.log.info('Deleting cluster %s.', self.cluster_name)
+        result = self.client.delete_cluster(cluster=self.cluster_name)
+
+        if self.wait_for_completion:
+            while not EcsClusterStateSensor(
+                task_id='await_cluster_delete',
+                cluster_name=self.cluster_name,
+                target_state=EcsClusterStates.INACTIVE,
+                failure_states={EcsClusterStates.FAILED},
+            ).poke(context):
+                # The sensor has a built-in delay and will try again until
+                # the cluster is deleted or reaches a failed state.
+                pass
+
+        return result['cluster']
+
+
+class EcsDeregisterTaskDefinitionOperator(EcsBaseOperator):
+    """
+    Deregister a task definition on AWS ECS.
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EcsDeregisterTaskDefinitionOperator`
+
+    :param task_definition: The family and revision (family:revision) or full Amazon Resource Name (ARN)
+        of the task definition to deregister. If you use a family name, you must specify a revision.
+    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
+    """
+
+    template_fields: Sequence[str] = ('task_definition', 'wait_for_completion')
+
+    def __init__(self, *, task_definition: str, wait_for_completion: bool = True, **kwargs):
+        super().__init__(**kwargs)
+        self.task_definition = task_definition
+        self.wait_for_completion = wait_for_completion
+
+    def execute(self, context: 'Context'):
+        self.log.info('Deregistering task definition %s.', self.task_definition)
+        result = self.client.deregister_task_definition(taskDefinition=self.task_definition)
+
+        if self.wait_for_completion:
+            while not EcsTaskDefinitionStateSensor(
+                task_id='await_deregister_task_definition',
+                task_definition=self.task_definition,
+                target_state=EcsTaskDefinitionStates.INACTIVE,
+            ).poke(context):
+                # The sensor has a built-in delay and will try again until the
+                # task definition is deregistered or reaches a failed state.
+                pass
+
+        return result['taskDefinition']['taskDefinitionArn']
+
+
+class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
+    """
+    Register a task definition on AWS ECS.
+
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:EcsRegisterTaskDefinitionOperator`
+
+    :param family: The family name of a task definition to create.
+    :param container_definitions: A list of container definitions in JSON format that describe
+        the different containers that make up your task.
+    :param register_task_kwargs: Extra arguments for Register Task Definition.
+    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
+    """
+
+    template_fields: Sequence[str] = (
+        'family',
+        'container_definitions',
+        'register_task_kwargs',
+        'wait_for_completion',
+    )
+
+    def __init__(
+        self,
+        *,
+        family: str,
+        container_definitions: List[Dict],
+        register_task_kwargs: Optional[Dict] = None,
+        wait_for_completion: bool = True,
+        **kwargs,
     ):
-        super().__init__()
-        self._event = Event()
+        super().__init__(**kwargs)
+        self.family = family
+        self.container_definitions = container_definitions
+        self.register_task_kwargs = register_task_kwargs or {}
+        self.wait_for_completion = wait_for_completion
 
-        self.fetch_interval = fetch_interval
+    def execute(self, context: 'Context'):
+        self.log.info(
+            'Registering task definition %s using the following values: %s',
+            self.family,
+            self.register_task_kwargs,
+        )
+        self.log.info('Using container definition %s', self.container_definitions)
+        response = self.client.register_task_definition(
+            family=self.family,
+            containerDefinitions=self.container_definitions,
+            **self.register_task_kwargs,
+        )
+        task_arn = response['taskDefinition']['taskDefinitionArn']
 
-        self.logger = logger
-        self.log_group = log_group
-        self.log_stream_name = log_stream_name
+        if self.wait_for_completion:
+            while not EcsTaskDefinitionStateSensor(
+                task_id='await_register_task_definition', task_definition=task_arn
+            ).poke(context):
+                # The sensor has a built-in delay and will try again until
+                # the task definition is registered or reaches a failed state.
+                pass
 
-        self.hook = AwsLogsHook(aws_conn_id=aws_conn_id, region_name=region_name)
-
-    def run(self) -> None:
-        logs_to_skip = 0
-        while not self.is_stopped():
-            time.sleep(self.fetch_interval.total_seconds())
-            log_events = self._get_log_events(logs_to_skip)
-            for log_event in log_events:
-                self.logger.info(self._event_to_str(log_event))
-                logs_to_skip += 1
-
-    def _get_log_events(self, skip: int = 0) -> Generator:
-        try:
-            yield from self.hook.get_log_events(self.log_group, self.log_stream_name, skip=skip)
-        except ClientError as error:
-            if error.response['Error']['Code'] != 'ResourceNotFoundException':
-                self.logger.warning('Error on retrieving Cloudwatch log events', error)
-
-            yield from ()
-        except ConnectionClosedError as error:
-            self.logger.warning('ConnectionClosedError on retrieving Cloudwatch log events', error)
-            yield from ()
-
-    def _event_to_str(self, event: dict) -> str:
-        event_dt = datetime.utcfromtimestamp(event['timestamp'] / 1000.0)
-        formatted_event_dt = event_dt.strftime('%Y-%m-%d %H:%M:%S,%f')[:-3]
-        message = event['message']
-        return f'[{formatted_event_dt}] {message}'
-
-    def get_last_log_messages(self, number_messages) -> list:
-        return [log['message'] for log in deque(self._get_log_events(), maxlen=number_messages)]
-
-    def get_last_log_message(self) -> Optional[str]:
-        try:
-            return self.get_last_log_messages(1)[0]
-        except IndexError:
-            return None
-
-    def is_stopped(self) -> bool:
-        return self._event.is_set()
-
-    def stop(self):
-        self._event.set()
+        context['ti'].xcom_push(key='task_definition_arn', value=task_arn)
+        return task_arn
 
 
-class EcsOperator(BaseOperator):
+class EcsRunTaskOperator(EcsBaseOperator):
     """
     Execute a task on AWS ECS (Elastic Container Service)
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:EcsOperator`
+        :ref:`howto/operator:EcsRunTaskOperator`
 
     :param task_definition: the task definition name on Elastic Container Service
     :param cluster: the cluster name on Elastic Container Service
@@ -216,15 +314,35 @@ class EcsOperator(BaseOperator):
     :param number_logs_exception: Number of lines from the last Cloudwatch logs to return in the
         AirflowException if an ECS task is stopped (to receive Airflow alerts with the logs of what
         failed in the code running in ECS).
+    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
     """
 
     ui_color = '#f0ede4'
-    template_fields: Sequence[str] = ('overrides',)
+    template_fields: Sequence[str] = (
+        'task_definition',
+        'cluster',
+        'overrides',
+        'launch_type',
+        'capacity_provider_strategy',
+        'group',
+        'placement_constraints',
+        'placement_strategy',
+        'platform_version',
+        'network_configuration',
+        'tags',
+        'awslogs_group',
+        'awslogs_region',
+        'awslogs_stream_prefix',
+        'awslogs_fetch_interval',
+        'propagate_tags',
+        'reattach',
+        'number_logs_exception',
+        'wait_for_completion',
+    )
     template_fields_renderers = {
         "overrides": "json",
         "network_configuration": "json",
         "tags": "json",
-        "quota_retry": "json",
     }
     REATTACH_XCOM_KEY = "ecs_task_arn"
     REATTACH_XCOM_TASK_ID_TEMPLATE = "{task_id}_task_arn"
@@ -235,8 +353,6 @@ class EcsOperator(BaseOperator):
         task_definition: str,
         cluster: str,
         overrides: dict,
-        aws_conn_id: Optional[str] = None,
-        region_name: Optional[str] = None,
         launch_type: str = 'EC2',
         capacity_provider_strategy: Optional[list] = None,
         group: Optional[str] = None,
@@ -253,12 +369,11 @@ class EcsOperator(BaseOperator):
         quota_retry: Optional[dict] = None,
         reattach: bool = False,
         number_logs_exception: int = 10,
+        wait_for_completion: bool = True,
         **kwargs,
     ):
         super().__init__(**kwargs)
 
-        self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
         self.task_definition = task_definition
         self.cluster = cluster
         self.overrides = overrides
@@ -280,13 +395,12 @@ class EcsOperator(BaseOperator):
         self.number_logs_exception = number_logs_exception
 
         if self.awslogs_region is None:
-            self.awslogs_region = region_name
+            self.awslogs_region = self.region
 
-        self.hook: Optional[AwsBaseHook] = None
-        self.client: Optional[EcsProtocol] = None
         self.arn: Optional[str] = None
         self.retry_args = quota_retry
         self.task_log_fetcher: Optional[EcsTaskLogFetcher] = None
+        self.wait_for_completion = wait_for_completion
 
     @provide_session
     def execute(self, context, session=None):
@@ -295,8 +409,6 @@ class EcsOperator(BaseOperator):
         )
         self.log.info('EcsOperator overrides: %s', self.overrides)
 
-        self.client = self.get_hook().get_conn()
-
         if self.reattach:
             self._try_reattach_task(context)
 
@@ -326,13 +438,15 @@ class EcsOperator(BaseOperator):
             self.task_log_fetcher.start()
 
             try:
-                self._wait_for_task_ended()
+                if self.wait_for_completion:
+                    self._wait_for_task_ended()
             finally:
                 self.task_log_fetcher.stop()
 
             self.task_log_fetcher.join()
         else:
-            self._wait_for_task_ended()
+            if self.wait_for_completion:
+                self._wait_for_task_ended()
 
         self._check_success_task()
 
@@ -375,25 +489,11 @@ class EcsOperator(BaseOperator):
 
         self.arn = response['tasks'][0]['taskArn']
         self.ecs_task_id = self.arn.split("/")[-1]
-        self.log.info(f"ECS task ID is: {self.ecs_task_id}")
+        self.log.info("ECS task ID is: %s", self.ecs_task_id)
 
         if self.reattach:
             # Save the task ARN in XCom to be able to reattach it if needed
-            self._xcom_set(
-                context,
-                key=self.REATTACH_XCOM_KEY,
-                value=self.arn,
-                task_id=self.REATTACH_XCOM_TASK_ID_TEMPLATE.format(task_id=self.task_id),
-            )
-
-    def _xcom_set(self, context, key, value, task_id):
-        XCom.set(
-            key=key,
-            value=value,
-            task_id=task_id,
-            dag_id=self.dag_id,
-            run_id=context["run_id"],
-        )
+            self.xcom_push(context, key=self.REATTACH_XCOM_KEY, value=self.arn)
 
     def _try_reattach_task(self, context):
         task_def_resp = self.client.describe_task_definition(taskDefinition=self.task_definition)
@@ -430,7 +530,8 @@ class EcsOperator(BaseOperator):
     def _aws_logs_enabled(self):
         return self.awslogs_group and self.awslogs_stream_prefix
 
-    def _get_task_log_fetcher(self) -> EcsTaskLogFetcher:
+    # TODO: When the deprecation wrapper below is removed, please fix the following return type hint.
+    def _get_task_log_fetcher(self) -> ecs.EcsTaskLogFetcher:
         if not self.awslogs_group:
             raise ValueError("must specify awslogs_group to fetch task logs")
         log_stream_name = f"{self.awslogs_stream_prefix}/{self.ecs_task_id}"
@@ -494,14 +595,6 @@ class EcsOperator(BaseOperator):
                         f"{container.get('reason', '').lower()}"
                     )
 
-    def get_hook(self) -> AwsBaseHook:
-        """Create and return an AwsHook."""
-        if self.hook:
-            return self.hook
-
-        self.hook = AwsBaseHook(aws_conn_id=self.aws_conn_id, client_type='ecs', region_name=self.region_name)
-        return self.hook
-
     def on_kill(self) -> None:
         if not self.client or not self.arn:
             return
@@ -515,48 +608,51 @@ class EcsOperator(BaseOperator):
         self.log.info(response)
 
 
-class ECSOperator(EcsOperator):
+class EcsOperator(EcsRunTaskOperator):
     """
     This operator is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsOperator`.
+    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsRunTaskOperator`.
     """
 
     def __init__(self, *args, **kwargs):
         warnings.warn(
             "This operator is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsOperator`.",
+            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsRunTaskOperator`.",
             DeprecationWarning,
             stacklevel=2,
         )
         super().__init__(*args, **kwargs)
 
 
-class ECSTaskLogFetcher(EcsTaskLogFetcher):
+class EcsTaskLogFetcher(ecs.EcsTaskLogFetcher):
     """
     This class is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsTaskLogFetcher`.
+    Please use :class:`airflow.providers.amazon.aws.hooks.ecs.EcsTaskLogFetcher`.
     """
 
+    # TODO: Note to deprecator, Be sure to fix the use of `ecs.EcsTaskLogFetcher`
+    #       in the Operators above when you remove this wrapper class.
     def __init__(self, *args, **kwargs):
         warnings.warn(
             "This class is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsTaskLogFetcher`.",
+            "Please use `airflow.providers.amazon.aws.hooks.ecs.EcsTaskLogFetcher`.",
             DeprecationWarning,
             stacklevel=2,
         )
         super().__init__(*args, **kwargs)
 
 
-class ECSProtocol(EcsProtocol):
+class EcsProtocol(ecs.EcsProtocol):
     """
     This class is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsProtocol`.
+    Please use :class:`airflow.providers.amazon.aws.hooks.ecs.EcsProtocol`.
     """
 
+    # TODO: Note to deprecator, Be sure to fix the use of `ecs.EcsProtocol`
+    #       in the Operators above when you remove this wrapper class.
     def __init__(self):
         warnings.warn(
-            "This class is deprecated. "
-            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsProtocol`.",
+            "This class is deprecated.  Please use `airflow.providers.amazon.aws.hooks.ecs.EcsProtocol`.",
             DeprecationWarning,
             stacklevel=2,
         )
